@@ -20,7 +20,7 @@ from ..utils._check_arrays import check_X_y
 
 
 class PolynomialNarmax(
-    GenerateRegressors, HouseHolder, InformationMatrix, ResiduesAnalysis, Estimators
+    Estimators, GenerateRegressors, HouseHolder, InformationMatrix, ResiduesAnalysis
 ):
     """Polynomial NARXMAX model
 
@@ -128,7 +128,6 @@ class PolynomialNarmax(
         n_info_values=10,
         estimator="recursive_least_squares",
         extended_least_squares=True,
-        aux_lag=1,
         lam=0.98,
         delta=0.01,
         offset_covariance=0.2,
@@ -143,7 +142,7 @@ class PolynomialNarmax(
         self._n_inputs = n_inputs
         self.ylag = ylag
         self.xlag = xlag
-        [self.regressor_code, self.max_lag] = GenerateRegressors().regressor_space(
+        [self.regressor_code, self.max_lag] = self.regressor_space(
             non_degree, xlag, ylag, n_inputs
         )
 
@@ -155,7 +154,6 @@ class PolynomialNarmax(
         self._eps = eps
         self._mu = mu
         self._offset_covariance = offset_covariance
-        self._aux_lag = aux_lag
         self._lam = lam
         self._delta = delta
         self._gama = gama
@@ -244,48 +242,42 @@ class PolynomialNarmax(
             e Novos Resultados
 
         """
-        squared_y = y[self.max_lag :].T @ y[self.max_lag :]
-        tmp_psi = np.array(psi)
-        y = np.array([y[self.max_lag :, 0]]).T
-        tmp_y = np.copy(y)
-        [n, dimension] = tmp_psi.shape
+        squared_y = np.dot(y[self.max_lag :].T, y[self.max_lag :])
+        tmp_psi = psi.copy()
+        y = y[self.max_lag :, 0].reshape(-1, 1)
+        tmp_y = y.copy()
+        dimension = tmp_psi.shape[1]
         piv = np.arange(dimension)
         tmp_err = np.zeros(dimension)
         err = np.zeros(dimension)
 
         for i in np.arange(0, dimension):
             for j in np.arange(i, dimension):
-                num = np.array(tmp_psi[i:n, j].T @ tmp_y[i:n])
-                num = np.power(num, 2)
-                den = np.array((tmp_psi[i:n, j].T @ tmp_psi[i:n, j]) * squared_y)
-                tmp_err[j] = num / den
+                # Add `eps` in the denominator to omit division by zero if
+                # denominator is zero
+                tmp_err[j] = (np.dot(tmp_psi[i:, j].T, tmp_y[i:]) ** 2) / (
+                    np.dot(tmp_psi[i:, j].T, tmp_psi[i:, j]) * squared_y + self._eps
+                )
 
             if i == process_term_number:
                 break
 
-            tmp_err = list(tmp_err)
-            piv_index = tmp_err.index(max(tmp_err[i:]))
+            piv_index = np.argmax(tmp_err[i:]) + i
             err[i] = tmp_err[piv_index]
             tmp_psi[:, [piv_index, i]] = tmp_psi[:, [i, piv_index]]
             piv[[piv_index, i]] = piv[[i, piv_index]]
-            x = tmp_psi[i:n, i]
 
-            v = HouseHolder()._house(x)
+            v = self._house(tmp_psi[i:, i])
 
-            aux_1 = tmp_psi[i:n, i:dimension]
+            row_result = self._rowhouse(tmp_psi[i:, i:], v)
 
-            row_result = HouseHolder()._rowhouse(aux_1, v)
+            tmp_y[i:] = self._rowhouse(tmp_y[i:], v)
 
-            tmp_y[i:n] = HouseHolder()._rowhouse(tmp_y[i:n], v)
-
-            tmp_psi[i:n, i:dimension] = np.copy(row_result)
+            tmp_psi[i:, i:] = np.copy(row_result)
 
         tmp_piv = piv[0:process_term_number]
-        tmp_psi = np.array(psi)
-        psi_orthogonal = np.copy(tmp_psi[:, tmp_piv])
-        tmp_psi = np.array(psi)
-        regressor_code_buffer = self.regressor_code
-        model_code = np.copy(regressor_code_buffer[tmp_piv, :])
+        psi_orthogonal = psi[:, tmp_piv]
+        model_code = self.regressor_code[tmp_piv, :].copy()
         return model_code, err, piv, psi_orthogonal
 
     def fit(self, X, y):
@@ -324,7 +316,7 @@ class PolynomialNarmax(
 
         check_X_y(X, y)
 
-        reg_Matrix = InformationMatrix().build_information_matrix(
+        reg_Matrix = self.build_information_matrix(
             X, y, self.xlag, self.ylag, self.non_degree
         )
 
@@ -346,28 +338,13 @@ class PolynomialNarmax(
             reg_Matrix, y, model_length
         )
 
-        # I know... the 'method' below needs attention
-        parameter_estimation = Estimators(
-            aux_lag=self.max_lag,
-            lam=self._lam,
-            delta=self._delta,
-            offset_covariance=self._offset_covariance,
-            mu=self._mu,
-            eps=self._eps,
-            gama=self._gama,
-            weight=self._weight,
-        )
-        self.theta = getattr(parameter_estimation, self.estimator)(psi, y)
+        self.theta = getattr(self, self.estimator)(psi, y)
 
         if self._extended_least_squares is True:
-            self.theta = self._unbiased_estimator(
-                psi, X, y, self.theta, self.max_lag, parameter_estimation
-            )
+            self.theta = self._unbiased_estimator(psi, X, y)
         return self
 
-    def _unbiased_estimator(
-        self, psi, X, y, biased_theta, aux_lag, parameter_estimation
-    ):
+    def _unbiased_estimator(self, psi, X, y):
         """Estimate the model parameters using Extended Least Squares method.
 
         Parameters
@@ -402,20 +379,20 @@ class PolynomialNarmax(
             https://en.wikipedia.org/wiki/Least_squares
 
         """
-        e = y[aux_lag:, 0].reshape(-1, 1) - psi @ biased_theta
+        e = y[self.max_lag :, 0].reshape(-1, 1) - np.dot(psi, self.theta)
         for i in range(30):
-            e = np.concatenate([np.zeros([aux_lag, 1]), e], axis=0)
+            e = np.concatenate([np.zeros([self.max_lag, 1]), e], axis=0)
             ee = np.concatenate([e, X], axis=1)
-            elag = [[1, aux_lag]] * ee.shape[1]
-            psi_extended = InformationMatrix().build_information_matrix(
-                ee, y, elag, 1, 2
-            )
+            elag = [[1, self.max_lag]] * ee.shape[1]
+            psi_extended = self.build_information_matrix(ee, y, elag, 1, 2)
 
             psi_extended = psi_extended[:, [2, 3, 7, 8, 11, 12, 13, 14, 15, 16, 17]]
 
             psi_e = np.concatenate([psi, psi_extended], axis=1)
-            unbiased_theta = getattr(parameter_estimation, self.estimator)(psi_e, y)
-            e = y[aux_lag:, 0].reshape(-1, 1) - psi_e @ unbiased_theta.reshape(-1, 1)
+            unbiased_theta = getattr(self, self.estimator)(psi_e, y)
+            e = y[self.max_lag :, 0].reshape(-1, 1) - np.dot(
+                psi_e, unbiased_theta.reshape(-1, 1)
+            )
 
         return unbiased_theta[0 : len(self.final_model), 0].reshape(-1, 1)
 
@@ -648,39 +625,24 @@ class PolynomialNarmax(
 
         output_vector = np.zeros(self.n_info_values)
         output_vector[:] = np.nan
-        X_base = InformationMatrix().build_information_matrix(
+        X_base = self.build_information_matrix(
             X, y, self.xlag, self.ylag, self.non_degree
         )
 
         n_samples = len(y) - self.max_lag
 
-        parameter_estimation = Estimators(
-            aux_lag=self.max_lag,
-            lam=self._lam,
-            delta=self._delta,
-            offset_covariance=self._offset_covariance,
-            mu=self._mu,
-            eps=self._eps,
-            gama=self._gama,
-            weight=self._weight,
-        )
-
         for i in range(0, self.n_info_values):
             n_theta = i + 1
             regressor_matrix = self.error_reduction_ratio(X_base, y, n_theta)[3]
 
-            tmp_theta = getattr(parameter_estimation, self.estimator)(
-                regressor_matrix, y
-            )
+            tmp_theta = getattr(self, self.estimator)(regressor_matrix, y)
 
-            tmp_yhat = regressor_matrix @ tmp_theta
+            tmp_yhat = np.dot(regressor_matrix, tmp_theta)
             tmp_residual = y[self.max_lag :] - tmp_yhat
             e_var = np.var(tmp_residual, ddof=1)
 
             output_vector[i] = self.compute_info_value(n_theta, n_samples, e_var)
 
-            # output_vector[i] = e_factor + model_factor
-
         return output_vector
 
     def results(self, theta_precision=4, err_precision=8, dtype="dec"):
