@@ -5,7 +5,7 @@ from sysidentpy.utils._check_arrays import (
     check_nan,
     check_X_y,
 )
-
+from sysidentpy.utils.generate_data import get_miso_data, get_siso_data
 import numpy as np
 from numpy.testing import assert_raises
 
@@ -44,3 +44,27 @@ def test_check_X_y():
     X = np.ones([10, 2])
     y = np.ones([8, 1])
     assert_raises(ValueError, check_X_y, X, y)
+
+
+def test_get_miso_data():
+    x_train, x_valid, y_train, y_valid = get_siso_data(
+        n=1000, colored_noise=False, sigma=0.001, train_percentage=90
+    )
+    assert len(x_train) == 900
+    assert len(x_valid) == 100
+    assert len(y_train) == 900
+    assert len(y_valid) == 100
+    assert x_train.shape[1] == 1
+    assert y_train.shape[1] == 1
+
+
+def test_get_miso_data():
+    x_train, x_valid, y_train, y_valid = get_miso_data(
+        n=1000, colored_noise=False, sigma=0.001, train_percentage=90
+    )
+    assert len(x_train) == 900
+    assert len(x_valid) == 100
+    assert len(y_train) == 900
+    assert len(y_valid) == 100
+    assert x_train.shape[1] == 2
+    assert y_train.shape[1] == 1
